%%%%%%%% Initializing parameters of model BY (--> struct param), example 'modelBY_init_HH.m'
%%%%%%%% Called 'SP' in the 2018--2019 paper
% Seasonality & population dynamics as in the Yoccoz-Birkeland model
% various interaction population dynamics / market
% lambda=1
% R(P)=logistic, R0=0 -> 1, degree 4
% D(P)=D_exp(P), D0=5, alpha=1
% m0=5
% rho = 0.21


%%%% Population dynamics
%
%	param: structure containing parameters of the model
%		param.A0: maturation age (minimal age taken into account in Nf, among the 'reproducing line')
param.A0=0.18;
%		param.A1: maximal age (maximal age taken into account in Nf, among the 'reproducing line')
param.A1=2;
%		param.Omega0: minimal age taken into account in the supply S (among the 'butchery line')
param.Omega0=0.18;
%		param.Omega1: maximal age taken into account in the supply S (among the 'butchery line')
param.Omega1=2;
%		param.m0: average number of female babies per year for a female of age >A0
param.m0=5;
%		'equilibrium' (R=R0, rho=1): m0=options.nb_steps/((kA1-kA0+1)*2*param.sexratio*param.R_param.R0)
%		param.sexratio: sex ratio (number of female babies / total number of babies) - default:1/2 - in general \in [0,1]
param.sexratio=0.5;
%       param.gamma: exponent of the nonlinear reproductivity 
param.gamma=8.25;
%       param.Nthresh: threshold at which reproductivity starts to be non linear
param.Nthresh=1;
%
%
%%%% Seasonality
%
%		param.rho_func: function used for computing rho(t). Its syntax must be z=rho_func(t,rho_param). 
param.rho_func=@rho_step;
%		param.rho_param: parameters to be given to the function rho_func
param.rho_param.rho_min=0;
param.rho_param.rho_summer=0.21;
%
%
%%%% Demand as a function of price (in price dynamics)
%
%		param.D_func: function used for computing D(P). Its syntax must be z=D_func(P,D_param). 
param.D_func=@D_exp;
%		param.D_param: parameters to be given to the function D_func
%	D_exp: D(P)=D0*exp(-alpha*P)
%		D_param.D0: constant in front of the exponential
%		D_param.alpha: exponential rate of decreasing of P (positive)
D_param.D0=5;
D_param.alpha=1;
param.D_param=D_param;
%
%
%%%% Interaction price/population dynamics
%
%		param.R_func: function used for computing R(P). Its syntax must be z=R_func(P,R_param). 
param.R_func=@R_logistic;
%
%		param.R_param: parameters to be given to the function R_func
%%% for R_logistic: R(P)=R0+(1-R0)*f(P/P_thresh) with f(0)=0, f(Inf)=1, f increasing fastly around 1
%		R_param.R0: (minimal) value of R, attained for P=0 (between 0 and 1)
%		R_param.P_thresh: threshold price at which R' is maximal
%		R_param.R_degree: integer >= 2, such that R is proportional to P^{R_degree} for P below P_thresh
R_param.R0=0;
R_param.R_degree=4;
R_param.P_thresh=1;
param.R_param=R_param;
%
%
%
%%%% Price dynamics as a function of demand & supply
%
%		param.F_func: function used for computing F(D,S). Its syntax must be z=F_func(D,S). 
param.F_func=@F_default;
%F_default: 	F(D,S)=(D-S)/(D+S)
%		param.lambda: multiplicative factor in front of F(D,S) in the market price dynamics
param.lambda=1;

